@@ -14,7 +14,7 @@ use warnings;
 
 use base qw{ Padre::Plugin };
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.2.0';
 
 
 # -- padre plugin api, refer to Padre::Plugin
@@ -48,15 +48,63 @@ sub autoformat {
     my $editor   = $current->editor;
     return unless $editor;
 
-    my $selected = $editor->GetSelectedText;
-    return unless $selected;
+    # no selection means autoformat current paragraph
+    if ( not $editor->GetSelectedText ) {
+        my ($b, $e) = $self->_find_current_paragraph;
+        return if $b == $e; # in between paragraphs
+        $editor->SetSelection($b, $e);
+    }
 
     require Text::Autoformat;
-    my $reformatted = Text::Autoformat::autoformat($selected);
-
-    $editor->ReplaceSelection($reformatted);
+    my $messy  = $editor->GetSelectedText;
+    my $tidied = Text::Autoformat::autoformat($messy);
+    $editor->ReplaceSelection($tidied);
 }
 
+
+# -- private methods
+
+#
+# my ($begin, $end) = $self->_current_paragraph;
+#
+# return $begin and $end position of current paragraph.
+#
+sub _current_paragraph {
+    my ($self) = @_;
+
+    my $editor = $self->main->current->editor;
+    my $curpos = $editor->GetCurrentPos;
+    my $lineno = $editor->LineFromPosition($curpos);
+
+    # check if we're in between paragraphs
+    return ($curpos, $curpos) if $editor->GetLine($lineno) =~ /^\s*$/;
+
+    # find the start of paragraph by searching backwards till we find a
+    # line with only whitespace in it.
+    my $para1 = $lineno;
+    while ( $para1 > 0 ) {
+        my $line = $editor->GetLine($para1);
+        last if $line =~ /^\s*$/;
+        $para1--;
+    }
+
+    # now, find the end of paragraph by searching forwards until we find
+    # only white space
+    my $lastline = $editor->GetLineCount;
+    my $para2 = $lineno;
+    while ( $para2 < $lastline ) {
+        $para2++;
+        my $line = $editor->GetLine($para2);
+        last if $line =~ /^\s*$/;
+    }
+
+    # return the position
+    my $begin = $editor->PositionFromLine($para1+1);
+    my $end   = $editor->PositionFromLine($para2);
+    return ($begin, $end);
+}
+
+
 1;
 __END__
 
